splearn.tests.datasets package
==============================

Submodules
----------

splearn.tests.datasets.get\_dataset\_path module
------------------------------------------------

.. automodule:: splearn.tests.datasets.get_dataset_path
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: splearn.tests.datasets
    :members:
    :undoc-members:
    :show-inheritance:
